==> chaosmesh-model-6.4.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface JVMChaosSpecFluent<A extends JVMChaosSpecFluent<A>> extends Fluent<A>{
  public String getAction();
  public A withAction(String action);
  public Boolean hasAction();
  public String getClassName();
  public A withClassName(String className);
  public Boolean hasClassName();
  public A addToContainerNames(Integer index,String item);
  public A setToContainerNames(Integer index,String item);
  public A addToContainerNames(java.lang.String... items);
  public A addAllToContainerNames(Collection<String> items);
  public A removeFromContainerNames(java.lang.String... items);
  public A removeAllFromContainerNames(Collection<String> items);
  public List<String> getContainerNames();
  public String getContainerName(Integer index);
  public String getFirstContainerName();
  public String getLastContainerName();
  public String getMatchingContainerName(Predicate<String> predicate);
  public Boolean hasMatchingContainerName(Predicate<String> predicate);
  public A withContainerNames(List<String> containerNames);
  public A withContainerNames(java.lang.String... containerNames);
  public Boolean hasContainerNames();
  public Integer getCpuCount();
  public A withCpuCount(Integer cpuCount);
  public Boolean hasCpuCount();
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public String getException();
  public A withException(String exception);
  public Boolean hasException();
  public Integer getLatency();
  public A withLatency(Integer latency);
  public Boolean hasLatency();
  public String getMemType();
  public A withMemType(String memType);
  public Boolean hasMemType();
  public String getMethod();
  public A withMethod(String method);
  public Boolean hasMethod();
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public String getRuleData();
  public A withRuleData(String ruleData);
  public Boolean hasRuleData();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSelectorSpec getSelector();
  public PodSelectorSpec buildSelector();
  public A withSelector(PodSelectorSpec selector);
  public Boolean hasSelector();
  public JVMChaosSpecFluent.SelectorNested<A> withNewSelector();
  public JVMChaosSpecFluent.SelectorNested<A> withNewSelectorLike(PodSelectorSpec item);
  public JVMChaosSpecFluent.SelectorNested<A> editSelector();
  public JVMChaosSpecFluent.SelectorNested<A> editOrNewSelector();
  public JVMChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item);
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public interface SelectorNested<N> extends Nested<N>,PodSelectorSpecFluent<JVMChaosSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface JVMChaosSpecFluent<A extends JVMChaosSpecFluent<A>> extends Fluent<A>{
  public String getAction();
  public A withAction(String action);
  public Boolean hasAction();
  public String getClassName();
  public A withClassName(String className);
  public Boolean hasClassName();
  public A addToContainerNames(int index,String item);
  public A setToContainerNames(int index,String item);
  public A addToContainerNames(java.lang.String... items);
  public A addAllToContainerNames(Collection<String> items);
  public A removeFromContainerNames(java.lang.String... items);
  public A removeAllFromContainerNames(Collection<String> items);
  public List<String> getContainerNames();
  public String getContainerName(int index);
  public String getFirstContainerName();
  public String getLastContainerName();
  public String getMatchingContainerName(Predicate<String> predicate);
  public Boolean hasMatchingContainerName(Predicate<String> predicate);
  public A withContainerNames(List<String> containerNames);
  public A withContainerNames(java.lang.String... containerNames);
  public Boolean hasContainerNames();
  public Integer getCpuCount();
  public A withCpuCount(Integer cpuCount);
  public Boolean hasCpuCount();
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public String getException();
  public A withException(String exception);
  public Boolean hasException();
  public Integer getLatency();
  public A withLatency(Integer latency);
  public Boolean hasLatency();
  public String getMemType();
  public A withMemType(String memType);
  public Boolean hasMemType();
  public String getMethod();
  public A withMethod(String method);
  public Boolean hasMethod();
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public String getRuleData();
  public A withRuleData(String ruleData);
  public Boolean hasRuleData();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSelectorSpec getSelector();
  public PodSelectorSpec buildSelector();
  public A withSelector(PodSelectorSpec selector);
  public Boolean hasSelector();
  public JVMChaosSpecFluent.SelectorNested<A> withNewSelector();
  public JVMChaosSpecFluent.SelectorNested<A> withNewSelectorLike(PodSelectorSpec item);
  public JVMChaosSpecFluent.SelectorNested<A> editSelector();
  public JVMChaosSpecFluent.SelectorNested<A> editOrNewSelector();
  public JVMChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item);
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public interface SelectorNested<N> extends Nested<N>,PodSelectorSpecFluent<JVMChaosSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}
